🔥 MCF
=============================================

MCF Interface
---------------
.. automodule:: novauniverse.interfaces.mcf
   :members:
   :undoc-members:
   :show-inheritance:

MCF Tournament Reference
--------------------------
.. automodule:: novauniverse.interfaces.mcf.mcf_tournament
   :members:
   :undoc-members:
   :show-inheritance: